@@ -1,5 +1,10 @@
 from typing import Dict, List, NamedTuple, Tuple, Union
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal  # noqa
+
 Source = Dict[str, Union[str, bool]]
 RequirementDict = Union[str, Dict[str, Union[bool, str]]]
 CandidateInfo = Tuple[List[str], str, str]
