@@ -15,6 +15,7 @@ from pdm.exceptions import ExtrasError, RequirementError
 from pdm.models.markers import Marker, get_marker, split_marker_extras
 from pdm.models.pip_shims import (
     InstallRequirement,
+    Link,
     install_req_from_editable,
     install_req_from_line,
     path_to_url,
@@ -31,7 +32,7 @@ from pdm.utils import (
 
 VCS_SCHEMA = ("git", "hg", "svn", "bzr")
 VCS_REQ = re.compile(
-    rf"(?P<vcs>{'|'.join(VCS_SCHEMA)})\+" r"(?P<url>[^\s;]+)(?P<marker>[\t ]*;[^\n]+)?"
+    rf"(?P<url>(?P<vcs>{'|'.join(VCS_SCHEMA)})\+[^\s;]+)(?P<marker>[\t ]*;[^\n]+)?"
 )
 FILE_REQ = re.compile(
     r"(?:(?P<url>\S+://[^\s\[\];]+)|"
@@ -72,6 +73,7 @@ class Requirement:
         "url",
         "path",
         "ref",
+        "revision",
         "index",
         "version",
         "allow_prereleases",
@@ -81,8 +83,8 @@ class Requirement:
     def __init__(self, **kwargs):
         self._marker = None
         self.from_section = "default"
-        self.marker_no_python = None  # type: Optional[Marker]
-        self.requires_python = PySpecSet()  # type: PySpecSet
+        self.marker_no_python: Optional[Marker] = None
+        self.requires_python = PySpecSet()
         for k, v in kwargs.items():
             if k == "specifier":
                 v = get_specifier(v)
@@ -144,7 +146,11 @@ class Requirement:
         for vcs in VCS_SCHEMA:
             if vcs in req_dict:
                 repo = req_dict[vcs]  # type: str
-                url = VcsRequirement._build_url_from_req_dict(name, repo, req_dict)
+                url = (
+                    vcs
+                    + "+"
+                    + VcsRequirement._build_url_from_req_dict(name, repo, req_dict)
+                )
                 return VcsRequirement(name=name, vcs=vcs, url=url, **req_dict)
         if "path" in req_dict or "url" in req_dict:
             return FileRequirement(name=name, **req_dict)
@@ -367,6 +373,8 @@ class NamedRequirement(Requirement, PackageRequirement):
 class VcsRequirement(FileRequirement):
     def __init__(self, **kwargs):
         self.repo = None
+        if not kwargs.get("vcs"):
+            kwargs["vcs"] = kwargs["url"].split("+", 1)[0]
         super().__init__(**kwargs)
 
     @classmethod
@@ -376,23 +384,25 @@ class VcsRequirement(FileRequirement):
         )
         return r
 
-    def as_line(self) -> str:
-        if self.editable:
-            return f"-e {self.vcs}+{self.url}{self._format_marker()}"
-        else:
-            extras = f"[{','.join(self.extras)}]" if self.extras else ""
-            ref = f"@{self.ref}" if self.ref else ""
-            return (
-                f"{self.project_name}{extras} @ {self.vcs}+{self.repo}"
-                f"{ref}{self._format_marker()}"
-            )
+    def as_ireq(self, **kwargs) -> InstallRequirement:
+        ireq = super().as_ireq(**kwargs)
+        if not self.editable and self.revision:
+            # For non-editable VCS requirements, commit-hash should be used as the
+            # rev-options for InstallRequirement to consume.
+            parsed = urlparse.urlparse(ireq.link.url)
+            new_path = "@".join((parsed.path.split("@", 1)[0], self.revision))
+            new_url = urlparse.urlunparse(parsed._replace(path=new_path))
+            ireq.link = Link(new_url)
+        return ireq
 
     def _parse_url(self) -> None:
-        if self.url.startswith("git@"):
-            self.url = add_ssh_scheme_to_git_uri(self.url)
+        vcs, url_no_vcs = self.url.split("+", 1)
+        if url_no_vcs.startswith("git@"):
+            url_no_vcs = add_ssh_scheme_to_git_uri(url_no_vcs)
+            self.url = f"{vcs}+{url_no_vcs}"
         if not self.name:
             self._parse_name_from_url()
-        repo = url_without_fragments(self.url)
+        repo = url_without_fragments(url_no_vcs)
         ref = None
         parsed = urlparse.urlparse(repo)
         if "@" in parsed.path:
@@ -410,12 +420,12 @@ class VcsRequirement(FileRequirement):
 
 
 def filter_requirements_with_extras(
-    requirment_lines: List[Union[str, Dict[str, Union[str, List[str]]]]],
+    requirement_lines: List[Union[str, Dict[str, Union[str, List[str]]]]],
     extras: Sequence[str],
 ) -> List[str]:
     result = []
     extras_in_meta = []
-    for req in requirment_lines:
+    for req in requirement_lines:
         if isinstance(req, dict):
             if req.get("extra"):
                 extras_in_meta.append(req["extra"])
@@ -435,7 +445,7 @@ def filter_requirements_with_extras(
 
     extras_not_found = [e for e in extras if e not in extras_in_meta]
     if extras_not_found:
-        warnings.warn(ExtrasError(extras_not_found), stacklevel=2)
+        warnings.warn(ExtrasError(extras_not_found))
 
     return result
 
@@ -447,7 +457,7 @@ def parse_requirement(line: str, editable: bool = False) -> Requirement:
         r = VcsRequirement.parse(line, m.groupdict())
     else:
         try:
-            r = NamedRequirement.parse(line)  # type: Requirement
+            r = NamedRequirement.parse(line)
         except (RequirementParseError, InvalidRequirement) as e:
             m = FILE_REQ.match(line)
             if m is not None:
@@ -456,9 +466,15 @@ def parse_requirement(line: str, editable: bool = False) -> Requirement:
                 raise RequirementError(str(e)) from None
         else:
             if r.url:
-                r = FileRequirement(
-                    name=r.name, url=r.url, extras=r.extras, marker=r.marker
-                )
+                link = Link(r.url)
+                if link.is_vcs:
+                    r = VcsRequirement(
+                        name=r.name, url=r.url, extras=r.extras, marker=r.marker
+                    )
+                else:
+                    r = FileRequirement(
+                        name=r.name, url=r.url, extras=r.extras, marker=r.marker
+                    )
 
     if editable:
         if r.is_vcs or r.is_file_or_url and r.is_local_dir:
