@@ -1,5 +1,7 @@
 from collections.abc import MutableMapping
+from pathlib import Path
 
+from pdm.formats import flit, poetry
 from pdm.pep517.metadata import Metadata
 
 
@@ -10,11 +12,22 @@ class MutableMetadata(Metadata, MutableMapping):
     """
 
     def __init__(self, filepath, data=None) -> None:
-        self.filepath = filepath
+        self.filepath = Path(filepath)
         if data is None:
-            data = self._read_pyproject(filepath)
+            data = self._read_pyproject(self.filepath)
         self._metadata = data
 
+    @staticmethod
+    def _read_pyproject(filepath):
+        try:
+            return Metadata._read_pyproject(filepath)
+        except ValueError:
+            for converter in (poetry, flit):
+                if converter.check_fingerprint(None, filepath):
+                    data, _ = converter.convert(None, filepath, None)
+                    return data
+            raise
+
     def __getitem__(self, k):
         return self._metadata[k]
 
