@@ -198,7 +198,7 @@ def convert_hashes(hashes: Dict[str, str]) -> Dict[str, List[str]]:
     The option format uses a str-list mapping. Keys are hash algorithms, and
     the list contains all values of that algorithm.
     """
-    result = {}
+    result: Dict[str, List[str]] = {}
     for hash_value in hashes.values():
         try:
             name, hash_value = hash_value.split(":")
@@ -243,24 +243,18 @@ def add_ssh_scheme_to_git_uri(uri: str) -> str:
     return uri
 
 
-def get_venv_python(root: Path) -> Optional[str]:
-    """Get the python interpreter path of venv"""
+def get_in_project_venv_python(root: Path) -> Optional[Path]:
+    """Get the python interpreter path of venv-in-project"""
     if os.name == "nt":
         suffix = ".exe"
         scripts = "Scripts"
     else:
         suffix = ""
         scripts = "bin"
-    venv = None
-    if "VIRTUAL_ENV" in os.environ:
-        venv = os.environ["VIRTUAL_ENV"]
-    else:
-        for possible_dir in ("venv", ".venv", "env"):
-            if (root / possible_dir / scripts / f"python{suffix}").exists():
-                venv = str(root / possible_dir)
-                break
-    if venv:
-        return os.path.join(venv, scripts, f"python{suffix}")
+    for possible_dir in ("venv", ".venv", "env"):
+        if (root / possible_dir / scripts / f"python{suffix}").exists():
+            venv = root / possible_dir
+            return venv / scripts / f"python{suffix}"
     return None
 
 
@@ -412,3 +406,27 @@ def is_venv_python(interpreter: os.PathLike) -> bool:
         else:
             return True
     return False
+
+
+def find_python_in_path(path: os.PathLike) -> Optional[Path]:
+    """Find a python interpreter from the given path, the input argument could be:
+
+    - A valid path to the interpreter
+    - A Python root directory that contains the interpreter
+    """
+    pathlib_path = Path(path).absolute()
+    if pathlib_path.is_file():
+        return pathlib_path
+
+    if os.name == "nt":
+        for root_dir in (pathlib_path, pathlib_path / "Scripts"):
+            if root_dir.joinpath("python.exe").exists():
+                return root_dir.joinpath("python.exe")
+    else:
+        executable_pattern = re.compile(r"python(?:\d(?:\.\d+m?)?)?$")
+
+        for python in pathlib_path.joinpath("bin").glob("python*"):
+            if executable_pattern.match(python.name):
+                return python
+
+    return None
